V1PlateReader
=============

.. currentmodule:: wwt_data_formats.plate

.. autoclass:: V1PlateReader
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~V1PlateReader.close
      ~V1PlateReader.read_tile

   .. rubric:: Methods Documentation

   .. automethod:: close
   .. automethod:: read_tile
